schemetools.SchemeVector
========================

.. abjad-lineage:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector

.. autoclass:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.force_quotes
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__str__
   :noindex:
